@@ -169,6 +169,11 @@ namespace DDM {
             stop();
         });
         connect(m_greeter, &Greeter::displayServerFailed, this, &Display::displayServerFailed);
+        connect(m_greeter, &Greeter::greeterStarted, this, [this] {
+            if (m_currentAuth) {
+                switchToUser(m_currentAuth->user());
+            }
+        });
     }
 
     Display::~Display() {
@@ -206,8 +211,42 @@ namespace DDM {
     }
 
     void Display::switchToUser(const QString &user) {
+        if (user == "dde") {
+            m_greeter->setUserActivated(false);
+        }
+
+        Auth *auth = nullptr;
+
+        for (auto *a : m_auths) {
+            if (a->user() == user) {
+                auth = a;
+                break;
+            }
+        }
+
+        if (!auth) {
+            return;
+        }
+
         auto* server = reinterpret_cast<SingleWaylandDisplayServer*>(m_displayServer);
         server->activateUser(user);
+
+        if (Logind::isAvailable()) {
+            OrgFreedesktopLogin1ManagerInterface manager(Logind::serviceName(), Logind::managerPath(), QDBusConnection::systemBus());
+            auto reply = manager.ListSessions();
+            reply.waitForFinished();
+
+            const auto info = reply.value();
+            for(const SessionInfo &s : reply.value()) {
+                if (s.userName == user) {
+                    OrgFreedesktopLogin1SessionInterface session(Logind::serviceName(), s.sessionPath.path(), QDBusConnection::systemBus());
+                    if (session.state() == "online" && session.vTNr() == static_cast<uint>(auth->tty())) {
+                        session.Activate();
+                        break;
+                    }
+                }
+            }
+        }
     }
 
     bool Display::start() {
@@ -270,6 +309,9 @@ namespace DDM {
         // start socket server
         m_socketServer->start(m_displayServer->display());
 
+        // Update dbus info
+        DaemonApp::instance()->displayManager()->setAuthInfo(m_socketServer->socketAddress());
+
         if (!daemonApp->testing()) {
             // change the owner and group of the socket to avoid permission denied errors
             struct passwd *pw = getpwnam("dde");
@@ -554,6 +596,10 @@ namespace DDM {
 
         Q_ASSERT(auth && auth->identifyOnly() == identifyOnly);
 
+        m_currentAuth = auth;
+        m_greeter->setUserActivated(success);
+        DaemonApp::instance()->displayManager()->setLastActivatedUser(user);
+
         if (success) {
             if (!m_reuseSessionId.isNull()) {
                 OrgFreedesktopLogin1ManagerInterface manager(Logind::serviceName(), Logind::managerPath(), QDBusConnection::systemBus());
@@ -586,6 +632,7 @@ namespace DDM {
                 }
             }
 
+            switchToUser(auth->user());
         }
         m_socket = nullptr;
     }
@@ -626,6 +673,11 @@ namespace DDM {
         // error happens (in this case we want to show the message from the
         // greeter
 
+        if (m_currentAuth == auth) {
+            m_currentAuth = nullptr;
+            DaemonApp::instance()->displayManager()->setLastActivatedUser("");
+        }
+
         m_auths.removeOne(auth);
         auth->deleteLater();
 
@@ -635,6 +687,9 @@ namespace DDM {
                 auto* server = reinterpret_cast<SingleWaylandDisplayServer*>(m_displayServer);
                 // TODO: switch to greeter
                 server->activateUser("dde");
+
+                // TODO: only current user logout will reset greeter state
+                m_greeter->setUserActivated(false);
                 return;
             }
         }
@@ -659,8 +714,7 @@ namespace DDM {
         qDebug() << "Session started" << success;
         Auth* auth = qobject_cast<Auth*>(sender());
         if (m_displayServerType == SingleCompositerServerType) {
-            auto* server = reinterpret_cast<SingleWaylandDisplayServer*>(m_displayServer);
-            server->activateUser(auth->user());
+            switchToUser(auth->user());
         }
 
         if (success && m_displayServerType != SingleCompositerServerType) {
