@@ -2,6 +2,8 @@
 // SPDX-License-Identifier: Apache-2.0 OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "SingleWaylandDisplayServer.h"
+#include "DaemonApp.h"
+#include "DisplayManager.h"
 #include "Messages.h"
 #include "SocketServer.h"
 #include "Constants.h"
@@ -9,6 +11,8 @@
 #include "Utils.h"
 #include "Display.h"
 
+#include <QDBusInterface>
+#include <QDBusConnection>
 #include <QStandardPaths>
 #include <QChar>
 #include <QLocalSocket>
@@ -23,39 +27,9 @@
 using namespace DDM;
 
 SingleWaylandDisplayServer::SingleWaylandDisplayServer(SocketServer *socketServer, Display *parent)
-    : DDM::WaylandDisplayServer(parent)
+    : DDM::DisplayServer(parent)
     , m_socketServer(socketServer)
-    , m_helper(new QProcess(this))
 {
-    QProcess *m_seatd = new QProcess(this);
-    m_seatd->setProgram("seatd");
-    m_seatd->setArguments({"-u", "dde", "-g", "dde", "-l", "debug"});
-    m_seatd->setProcessEnvironment([] {
-        auto env = QProcessEnvironment::systemEnvironment();
-        env.insert("SEATD_VTBOUND", "0");
-        return env;
-    }());
-    connect(m_seatd, &QProcess::readyReadStandardOutput, this, [m_seatd] {
-        qInfo() << m_seatd->readAllStandardOutput();
-    });
-    connect(m_seatd, &QProcess::readyReadStandardError, this, [m_seatd] {
-        qWarning() << m_seatd->readAllStandardError();
-    });
-
-    connect(m_helper, &QProcess::readyReadStandardOutput, this, [this] {
-        qInfo() << m_helper->readAllStandardOutput();
-    });
-    connect(m_helper, &QProcess::readyReadStandardError, this, [this] {
-        qWarning() << m_helper->readAllStandardError();
-    });
-
-    m_seatd->start();
-
-    QString socketName = QStringLiteral("treeland-helper-%1").arg(generateName(6));
-
-    // log message
-    qDebug() << "Socket server started.";
-
     connect(m_socketServer, &SocketServer::connected, this, [this, parent](QLocalSocket *socket) {
         m_greeterSockets << socket;
     });
@@ -69,6 +43,62 @@ SingleWaylandDisplayServer::SingleWaylandDisplayServer(SocketServer *socketServe
     });
 }
 
+SingleWaylandDisplayServer::~SingleWaylandDisplayServer() {
+    stop();
+}
+
+QString SingleWaylandDisplayServer::sessionType() const
+{
+    return QStringLiteral("wayland");
+}
+
+void SingleWaylandDisplayServer::setDisplayName(const QString &displayName)
+{
+    m_display = displayName;
+}
+
+bool SingleWaylandDisplayServer::start()
+{
+    // Check flag
+    if (m_started)
+        return false;
+
+    // Start treeland service
+    QDBusInterface systemd("org.freedesktop.systemd1", "/org/freedesktop/systemd1", "org.freedesktop.systemd1.Manager", QDBusConnection::systemBus());
+    systemd.call("StartUnit", "treeland.service", "replace");
+
+    // TODO: check treeland service
+
+    // Set flag
+    m_started = true;
+    emit started();
+
+    return true;
+}
+
+void SingleWaylandDisplayServer::stop()
+{
+    // Check flag
+    if (!m_started)
+        return;
+
+    // Stop treeland service
+    QDBusInterface systemd("org.freedesktop.systemd1", "/org/freedesktop/systemd1", "org.freedesktop.systemd1.Manager", QDBusConnection::systemBus());
+    systemd.call("StopUnit", "treeland.service", "replace");
+
+    // Reset flag
+    m_started = false;
+    emit stopped();
+}
+
+void SingleWaylandDisplayServer::finished()
+{
+}
+
+void SingleWaylandDisplayServer::setupDisplay()
+{
+}
+
 void SingleWaylandDisplayServer::activateUser(const QString &user) {
     for (auto greeter : m_greeterSockets) {
         if (user == "dde") {
