@@ -14,6 +14,4 @@ public:
 
 private:
     QProcess *m_process;
-    int m_wCompositorCrashCount;
-    int m_maxCrashCountLimit;
 };
